@@ -52,10 +52,11 @@ L<https://github.com/iafan/Config-Neat>
 
 package Config::Neat::Schema;
 
-our $VERSION = '1.204';
+our $VERSION = '1.3';
 
 use strict;
 
+use Config::Neat::Array;
 use Config::Neat::Inheritable;
 use Config::Neat::Util qw(new_ixhash is_hash is_any_hash is_any_array is_simple_array is_neat_array hash_has_sequential_keys);
 use File::Spec::Functions qw(rel2abs);
@@ -143,7 +144,7 @@ sub validate_node {
 
     # automatic casting from ARRAY to BOOLEAN
     if ($schema_type eq 'BOOLEAN' and $data_type eq 'ARRAY') {
-        warn "Warning: '".$data_node->as_string."' is not a valid boolean number\n" unless $data_node->is_boolean;
+        die "'".$data_node->as_string."' is not a valid boolean number\n" unless $data_node->is_boolean;
         $parent_data->{$parent_data_key} = $data_node = $data_node->as_boolean;
         $data_type = $schema_type;
     }
@@ -178,6 +179,11 @@ sub validate_node {
         die "'$pathstr' is $data_type, while it is expected to be $schema_type";
     }
 
+    if ($data_type eq 'ARRAY') {
+        # flatten the array
+        $parent_data->{$parent_data_key} = $data_node->as_flat_array;
+    }
+
     if ($data_type eq 'HASH') {
         foreach my $key (keys %$data_node) {
             my @a = @$path;
@@ -194,7 +200,7 @@ sub validate_node {
 
     if ($cast_to_array) {
         my @a = values %$data_node;
-        $parent_data->{$parent_data_key} = \@a;
+        $parent_data->{$parent_data_key} = Config::Neat::Array->new(\@a);
     }
 
     return 1;
